package com.loafle.bridge.collector;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.loafle.bridge.Application;
import org.apache.log4j.Logger;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.WebIntegrationTest;
import org.springframework.http.MediaType;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;
import org.springframework.test.web.servlet.MockMvc;

import java.util.Date;

import static org.hamcrest.CoreMatchers.equalTo;
import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.get;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.content;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.status;
import static org.springframework.test.web.servlet.setup.MockMvcBuilders.standaloneSetup;

/**
 * Created by root on 16. 11. 16.
 */

@RunWith(SpringJUnit4ClassRunner.class)
@ContextConfiguration(classes = Application.class)
@WebIntegrationTest
public class CollectorControllerTest {

    private MockMvc mockMvc;

    @Autowired
    private CollectorRepository repo;

    @Autowired
    private CollectorController controller;

    Logger l = Logger.getLogger(this.getClass());


    @Before
    public void Before() {

        mockMvc = standaloneSetup(controller).build();
        Collector c = new Collector();
        c.setVersion("1.0.0");
        c.setConfigPath("/root");
        c.setInstallDate(new Date());
        c.setUpdateDate(new Date());
        c.setLicenseDueDate(new Date());
        c.setProductId("1111111");
        repo.save(c);
    }


    @After
    public void After() {
        repo.deleteAll();
    }

    private String jsonStringFromObject(Object object) throws JsonProcessingException {
        ObjectMapper mapper = new ObjectMapper();
        return mapper.writeValueAsString(object);
    }

    @Test
    public void TestGetCollectorbyProductionId () throws Exception {

        Collector c = repo.findAll().get(0);
        String jsonString = jsonStringFromObject(c);
        l.debug("!!!!!!!!" + jsonString);
        mockMvc.perform(get("/collector/{productId}", c.getProductId()))
                .andExpect(status().isOk())
                .andExpect(content().contentTypeCompatibleWith(MediaType.APPLICATION_JSON))
                .andExpect(content().string(equalTo(jsonString)));

    }


}